@@ -1,7 +1,7 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
    Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.5
+   topkg v1.0.7
   ---------------------------------------------------------------------------*)
 
 open Topkg_result
@@ -560,7 +560,13 @@ module OCaml = struct
     get_bool_stdlib_file_exists_discovery "native" c ~file ~on_error:false
 
   let native_dynlink c =
-    let file _ = "dynlink.cmxa" in
+    let file c =
+      let (major_ocaml_version, _minor, _patch, _extra) = version c in
+      if major_ocaml_version >= 5 then
+        "dynlink/dynlink.cmxa"
+      else
+        "dynlink.cmxa"
+    in
     get_bool_stdlib_file_exists_discovery "natdynlink" c ~file ~on_error:false
 
   let supports_shared_libraries c =
