@@ -1,15 +1,16 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
    Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.5
+   topkg v1.0.7
   ---------------------------------------------------------------------------*)
 
-type ext = [ `Ext of string | `Obj | `Lib | `Dll | `Exe ]
+type ext = [ `Ext of string | `Obj | `Real_clib | `Lib | `Dll | `Exe ]
 type t = ext list
 
 let interface = [ `Ext ".mli"; `Ext ".cmi"; `Ext ".cmti"; ]
 let cmx = [ `Ext ".cmx" ]
 let api = interface @ cmx
+let real_c_library = [ `Real_clib ]
 let c_library = [ `Lib ]
 let c_dll_library = [ `Dll ]
 let library = [` Ext ".cma"; `Ext ".cmxa"; `Ext ".cmxs" ] @ c_library
@@ -26,7 +27,7 @@ let ext_to_string c =
   function
   | `Ext s -> s
   | `Obj -> ext_obj
-  | `Lib -> ext_lib
+  | `Lib | `Real_clib -> ext_lib
   | `Dll -> ext_dll
   | `Exe -> ext_exe
 
